/* --------------------------------------------------------------  */
/* (C)Copyright 2007                                               */
/* International Business Machines Corporation                     */
/* All Rights Reserved.                                            */
/*                                                                 */
/* Redistribution and use in source and binary forms, with or      */
/* without modification, are permitted provided that the           */
/* following conditions are met:                                   */
/*                                                                 */
/* - Redistributions of source code must retain the above copyright*/
/*   notice, this list of conditions and the following disclaimer. */
/*                                                                 */
/* - Redistributions in binary form must reproduce the above       */
/*   copyright notice, this list of conditions and the following   */
/*   disclaimer in the documentation and/or other materials        */
/*   provided with the distribution.                               */
/*                                                                 */
/* - Neither the name of IBM Corporation nor the names of its      */
/*   contributors may be used to endorse or promote products       */
/*   derived from this software without specific prior written     */
/*   permission.                                                   */
/*                                                                 */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND          */
/* CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,     */
/* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF        */
/* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE        */
/* DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR            */
/* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,    */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT    */
/* NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;    */
/* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)        */
/* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN       */
/* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR    */
/* OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,  */
/* EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              */
/* --------------------------------------------------------------  */
/* PROLOG END TAG zYx                                              */

/* *****************************************************************************
 * Purpose : Prototypes for BLAS functions   
 *     
 **************************************************************************** */

#ifndef __BLAS_H__
#define __BLAS_H__

    // SP level 1 //
    extern double snrm2_(int *, float *, int *);
    extern double sasum_(int *, float *, int *);
    extern int sswap_(int *, float *, int *, float *, int *);
    extern int srot_(int *, float *, int *, float *, int *, float *, float *);
    extern int srotg_(float *, float *, float *, float *);
    extern int sscal_(int *, float *, float *, int *);
    extern int isamax_(int *, float *, int *);
    extern double sdot_(int *, float *, int *, float *, int *);
    extern int scopy_(int *, float *, int *, float *, int *);
    extern int saxpy_(int *, float *, float *, int *, float *, int *) ;

    // DP level 1 //
    extern int drotg_(double *, double *, double *, double *);
    extern double dnrm2_(int *, double *, int *);
    extern double dasum_(int *, double *, int *);
    extern int dswap_(int *, double *, int *, double *, int *);
    extern int drot_(int *, double *, int *, double *, int *, double *, double *);
    extern int idamax_(int *, double *, int *);
    extern int dscal_(int *, double *, double *, int *);
    extern double ddot_(int *, double *, int *, double *, int *);
    extern int dcopy_(int *, double *, int *, double *, int *);
    extern int daxpy_(int *, double *, double *, int *, double *, int *); 


    // SP level 2 //
    extern int sgbmv_(char *, int *, int *, int * , int *, float *, float *, int *, float *, int *, float *, float *, int *);
    extern int sspmv_(char *, int *, float *, float *, float *, int *, float *, float *, int *);
    extern int ssymv_(char *, int *, float *, float *, int *, float *, int *, float *, float *, int *);
    extern int sgemv_(char *, int *, int * , float *, float *, int *, float *, int *, float *, float *, int *);
    extern int ssbmv_(char *, int *, int *, float *, float *, int *, float *, int *, float *, float *, int *);
    extern int stpmv_(char *, char *, char *, int *, float *, float *, int *);
    extern int strmv_(char *, char *, char *, int *, float *, int *, float *, int *);
    extern int stpsv_(char *, char *, char *, int *, float *, float *, int *);
    extern int strsv_(char *, char *, char *, int *, float *, int *, float *, int *);
    extern int stbmv_(char *, char *, char *, int *, int *, float *, int *, float *, int *);
    extern int stbsv_(char *, char *, char *, int *, int *, float *, int *, float *, int *);
    extern int sger_(int *, int *, float *, float *, int *, float *, int *, float *, int *);
    extern int sspr_(char *, int *, float *, float *, int *, float *);
    extern int ssyr_(char *, int *, float *, float *, int *, float *, int *);
    extern int ssyr2_(char *, int *, float *, float *, int *, float *, int *, float *, int *);
    extern int sspr2_(char *, int *, float *, float *, int *, float *, int *, float *);

    // DP level 2 //
    extern int dgbmv_(char *, int *, int *, int * , int *, double *, double *, int *, double *, int *, double *, double *, int *);
    extern int dgemv_(char *, int *, int *, double *, double *, int *, double *, int *, double *, double *, int *);
    extern int dsymv_(char *, int *, double *, double *, int *, double *, int *, double *, double *, int *);
    extern int dsbmv_(char *, int *, int *, double *, double *, int *, double *, int *, double *, double *, int *);
    extern int dspmv_(char *, int *, double *, double *, double *, int *, double *, double *, int *);
    extern int dtpmv_(char *, char *, char *, int *, double *, double *, int *);
    extern int dtrmv_(char *, char *, char *, int *, double *, int *, double *, int *);
    extern int dtpsv_(char *, char *, char *, int *, double *, double *, int *);
    extern int dtbmv_(char *, char *, char *, int *, int *, double *, int *, double *, int *);
    extern int dtrsv_(char *, char *, char *, int *, double *, int *, double *, int *);
    extern int dtbsv_(char *, char *, char *, int *, int *, double *, int *, double *, int *);
    extern int dger_(int *, int *, double *, double *, int *, double *, int *, double *, int *);
    extern int dsyr_(char *, int *, double *, double *, int *, double *, int *);
    extern int dspr_(char *, int *, double *, double *, int *, double *);
    extern int dspr2_(char *, int *, double *, double *, int *, double *, int *, double *);
    extern int dsyr2_(char *, int *, double *, double *, int *, double *, int *, double *, int *);

    // SP level 3 //
    extern int sgemm_(char *, char *, int *, int *, int *, float *, float *, 
                      int *, float *, int *, float *, float *, int *);
    extern int ssyrk_(char *, char *, int *, int *, float *, float *, int *, 
                      float *, float *, int *);
    extern int strsm_(char *, char *, char *, char *, int *, int *, float *, 
                      float *, int *, float *, int *);
    extern int strmm_(char *, char *, char *, char *, int *, int *, float *, 
                      float *, int *, float *, int *);
    extern int ssymm_(char *, char *, int *, int *, float *, float *, int *, 
                      float *, int *, float *, float *, int *);
    extern int ssyr2k_(char *, char *, int *, int *, float *, float *, int *,
                       float *, int *, float *, float *, int *);

    //DP level 3 //
    extern int dgemm_(char *, char *, int *, int *, int *, double *, double *, 
                      int *, double *, int *, double *, double *, int *); 
    extern int dsyrk_(char *, char *, int *, int *,
                      double *, double *, int *, double *, double *, int *);
    extern int dtrsm_(char *, char *, char *, char *, int *, int *,
                      double *, double *, int *, double *, int *);
    extern int dtrmm_(char *, char *, char *, char *, int *, int *,
                      double *, double *, int *, double *, int *);
    extern int dsyr2k_(char *, char *, int *, int *, double *, double *, 
                       int *, double *, int *, double *, double *, int *);
    extern int dsymm_(char *, char *, int *, int *, double *, double *, int *, double *, int *,
                      double *, double *, int *);

#endif
