/* --------------------------------------------------------------  */
/* (C)Copyright 2007                                               */
/* International Business Machines Corporation                     */
/* All Rights Reserved.                                            */
/*                                                                 */
/* Redistribution and use in source and binary forms, with or      */
/* without modification, are permitted provided that the           */
/* following conditions are met:                                   */
/*                                                                 */
/* - Redistributions of source code must retain the above copyright*/
/*   notice, this list of conditions and the following disclaimer. */
/*                                                                 */
/* - Redistributions in binary form must reproduce the above       */
/*   copyright notice, this list of conditions and the following   */
/*   disclaimer in the documentation and/or other materials        */
/*   provided with the distribution.                               */
/*                                                                 */
/* - Neither the name of IBM Corporation nor the names of its      */
/*   contributors may be used to endorse or promote products       */
/*   derived from this software without specific prior written     */
/*   permission.                                                   */
/*                                                                 */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND          */
/* CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,     */
/* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF        */
/* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE        */
/* DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR            */
/* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,    */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT    */
/* NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;    */
/* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)        */
/* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN       */
/* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR    */
/* OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,  */
/* EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              */
/* --------------------------------------------------------------  */
/* PROLOG END TAG zYx                                              */


/* **********************************************************************

   -- Purpose   :Prototypes for kernel routines 
                  
************************************************************************* */

#ifndef __BLAS_S_H__

#define __BLAS_S_H__

// level 1 //

void daxpy_spu( double *x, double *y, double alpha, int len ) ;
void saxpy_spu( float *x, float *y, float alpha, int len ) ;

void dcopy_spu ( double *x, double *y, int len ) ;
void scopy_spu ( float *x, float *y, int len ) ;

double ddot_spu( double *x, double *y, int len ) ;
float sdot_spu( float *x, float *y, int len ) ;

void dscal_spu( double *x, double alpha, int len ) ;
void sscal_spu( float *x, float alpha, int len ) ;

int idamax_spu( double *x, int len ) ;
int isamax_spu( float *x, int len ) ;

// level 2 //

void dgemv_spu(int m, int n, double alpha, double *a, double *x, double *y); 
void sgemv_spu(int m, int n, float alpha, float *a, float *x, float *y); 

// level 3 //

void dgemm_spu( int M, int N, int K, double *A, double *B, double *C );
void sgemm_spu( int M, int N, int K, float *A, float *B, float *C );

void dtrsm_spu(int m, int n, double *aa, double *bb);
void strsm_spu(int m, int n, float *aa, float *bb);
void strsm_64x64( float* A, float* B);

void  ssyrk_64x64(float *blkA, float *blkC, float *Alpha) ;

#endif
